@@ -3,3 +3,6 @@
 !       if f90 is available, USEFORMULA will permit to use
 !        mathmatical formula in config file
 #undef  USEFORMULA
+
+#undef  LightINTINFO
+#undef  OtherINTINFO
